@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -56,32 +56,32 @@ void ThunderbirdSettings::importSettings()
     QTextStream stream(&file);
     while (!stream.atEnd()) {
         const QString line = stream.readLine();
-        if (line.startsWith(QStringLiteral("user_pref"))) {
-            if (line.contains(QStringLiteral("mail.smtpserver")) ||
-                    line.contains(QStringLiteral("mail.server.")) ||
-                    line.contains(QStringLiteral("mail.identity.")) ||
-                    line.contains(QStringLiteral("mail.account.")) ||
-                    line.contains(QStringLiteral("mail.accountmanager.")) ||
-                    line.contains(QStringLiteral("mailnews.")) ||
-                    line.contains(QStringLiteral("mail.compose.")) ||
-                    line.contains(QStringLiteral("mail.spellcheck")) ||
-                    line.contains(QStringLiteral("mail.SpellCheckBeforeSend")) ||
-                    line.contains(QStringLiteral("spellchecker.dictionary")) ||
-                    line.contains(QStringLiteral("ldap_")) ||
-                    line.contains(QStringLiteral("mail.biff.")) ||
-                    line.contains(QStringLiteral("mailnews.tags.")) ||
-                    line.contains(QStringLiteral("extensions.AutoResizeImage.")) ||
-                    line.contains(QStringLiteral("mail.phishing.")) ||
-                    line.contains(QStringLiteral("mail.display_glyph")) ||
-                    line.contains(QStringLiteral("extensions.sieve.account."))) {
+        if (line.startsWith(QLatin1String("user_pref"))) {
+            if (line.contains(QLatin1String("mail.smtpserver")) ||
+                    line.contains(QLatin1String("mail.server.")) ||
+                    line.contains(QLatin1String("mail.identity.")) ||
+                    line.contains(QLatin1String("mail.account.")) ||
+                    line.contains(QLatin1String("mail.accountmanager.")) ||
+                    line.contains(QLatin1String("mailnews.")) ||
+                    line.contains(QLatin1String("mail.compose.")) ||
+                    line.contains(QLatin1String("mail.spellcheck")) ||
+                    line.contains(QLatin1String("mail.SpellCheckBeforeSend")) ||
+                    line.contains(QLatin1String("spellchecker.dictionary")) ||
+                    line.contains(QLatin1String("ldap_")) ||
+                    line.contains(QLatin1String("mail.biff.")) ||
+                    line.contains(QLatin1String("mailnews.tags.")) ||
+                    line.contains(QLatin1String("extensions.AutoResizeImage.")) ||
+                    line.contains(QLatin1String("mail.phishing.")) ||
+                    line.contains(QLatin1String("mail.display_glyph")) ||
+                    line.contains(QLatin1String("extensions.sieve.account."))) {
                 insertIntoMap(line);
             }
         } else {
             if (!line.startsWith(QLatin1Char('#')) ||
                     line.isEmpty() ||
-                    line.startsWith(QStringLiteral("/*")) ||
-                    line.startsWith(QStringLiteral(" */")) ||
-                    line.startsWith(QStringLiteral(" *"))) {
+                    line.startsWith(QLatin1String("/*")) ||
+                    line.startsWith(QLatin1String(" */")) ||
+                    line.startsWith(QLatin1String(" *"))) {
                 qCDebug(THUNDERBIRDPLUGIN_LOG) << " unstored line :" << line;
             }
 
@@ -224,10 +224,10 @@ void ThunderbirdSettings::readExtensionsSettings()
     const QString filteringRenamingPatternStr(QStringLiteral("extensions.AutoResizeImage.renamingPattern"));
     if (mHashConfig.contains(filteringRenamingPatternStr)) {
         QString filteringRenamingPattern = mHashConfig.value(filteringRenamingPatternStr).toString();
-        filteringRenamingPattern.replace(QStringLiteral("%3Fn"), QStringLiteral("%n"));
-        filteringRenamingPattern.replace(QStringLiteral("%3Ft"), QStringLiteral("%t"));
-        filteringRenamingPattern.replace(QStringLiteral("%3Fd"), QStringLiteral("%d"));
-        filteringRenamingPattern.replace(QStringLiteral("%3Fe"), QStringLiteral("%e"));
+        filteringRenamingPattern.replace(QLatin1String("%3Fn"), QLatin1String("%n"));
+        filteringRenamingPattern.replace(QLatin1String("%3Ft"), QLatin1String("%t"));
+        filteringRenamingPattern.replace(QLatin1String("%3Fd"), QLatin1String("%d"));
+        filteringRenamingPattern.replace(QLatin1String("%3Fe"), QLatin1String("%e"));
         addKmailConfig(QStringLiteral("AutoResizeImage"), QStringLiteral("rename-resized-images-pattern"), filteringRenamingPattern);
     }
 
@@ -762,13 +762,8 @@ void ThunderbirdSettings::readAccount()
         } else if (type == QLatin1String("none")) {
             //FIXME look at if we can implement it
             qCDebug(THUNDERBIRDPLUGIN_LOG) << " account type none!";
-        } else if (type == QLatin1String("movemail")) {
-            qCDebug(THUNDERBIRDPLUGIN_LOG) << " movemail accound found and not implemented in importthunderbird";
-        } else if (type == QLatin1String("rss")) {
-            qCDebug(THUNDERBIRDPLUGIN_LOG) << " rss resource needs to be implemented";
-            continue;
-        } else if (type == QLatin1String("nntp")) {
-            qCDebug(THUNDERBIRDPLUGIN_LOG) << " nntp resource need to be implemented";
+        } else if (type == QLatin1String("rss") || type == QLatin1String("nntp") || type == QLatin1String("movemail")) {
+            qCDebug(THUNDERBIRDPLUGIN_LOG) << QStringLiteral("%1 rss resource needs to be implemented").arg(type);
             continue;
         } else {
             qCDebug(THUNDERBIRDPLUGIN_LOG) << " type unknown : " << type;
@@ -1023,12 +1018,12 @@ void ThunderbirdSettings::insertIntoMap(const QString &line)
             mHashConfig.insert(key, value);
         }
     }
-    if (key.contains(QStringLiteral("ldap_")) && key.endsWith(QStringLiteral(".description"))) {
+    if (key.contains(QLatin1String("ldap_")) && key.endsWith(QLatin1String(".description"))) {
         QString ldapAccountName = key;
         mLdapAccountList.append(ldapAccountName.remove(QStringLiteral(".description")));
     }
-    if (key.contains(QStringLiteral("mailnews.tags.")) &&
-            (key.endsWith(QStringLiteral(".color")) || key.endsWith(QStringLiteral(".tag")))) {
+    if (key.contains(QLatin1String("mailnews.tags.")) &&
+            (key.endsWith(QLatin1String(".color")) || key.endsWith(QLatin1String(".tag")))) {
         QString name = key;
         name.remove(QStringLiteral("mailnews.tags."));
         name.remove(QStringLiteral(".color"));
@@ -1038,7 +1033,7 @@ void ThunderbirdSettings::insertIntoMap(const QString &line)
             tag = mHashTag.value(name);
             mHashTag.remove(name);
         }
-        if (key.endsWith(QStringLiteral(".color"))) {
+        if (key.endsWith(QLatin1String(".color"))) {
             tag.color = QColor(mHashConfig.value(key).toString());
         } else {
             tag.name = mHashConfig.value(key).toString();
